@@ -20,7 +20,7 @@ module Vlad
 
   ##
   # This is the version of Vlad you are running.
-  VERSION = '1.3.2'
+  VERSION = '2.0.0'
 
   ##
   # Base error class for all Vlad errors.
@@ -42,7 +42,7 @@ module Vlad
   # Loads tasks file +tasks_file+ and various recipe styles as a hash
   # of category/style pairs. Recipes default to:
   #
-  #     :app    => :mongrel
+  #     :app    => :passenger
   #     :config => 'config/deploy.rb'
   #     :core   => :core
   #     :scm    => :subversion
@@ -62,7 +62,7 @@ module Vlad
     order += options.keys - order
 
     recipes = {
-      :app    => :mongrel,
+      :app    => :passenger,
       :config => 'config/deploy.rb',
       :core   => :core,
       :scm    => :subversion,
