@@ -3,6 +3,6 @@ require 'vlad'
 namespace :vlad do
   desc 'Restart Passenger'
   remote_task :start_app, :roles => :app do
-    run "touch #{release_path}/tmp/restart.txt"
+    run "touch #{latest_release}/tmp/restart.txt"
   end
-end
\ No newline at end of file
+end
